==> gimp-1.3.3.tar.bz2: gimp-1.3.3/app/core/gimpimage-projection.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattisbvf
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_PROJECTION_H__
#define __GIMP_IMAGE_PROJECTION_H__


void            gimp_image_projection_allocate     (GimpImage       *gimage);
void            gimp_image_projection_free         (GimpImage       *gimage);

TileManager   * gimp_image_projection              (GimpImage       *gimage);
GimpImageType	gimp_image_projection_type         (const GimpImage *gimage);
gint            gimp_image_projection_bytes        (const GimpImage *gimage);
gint            gimp_image_projection_opacity      (const GimpImage *gimage);

guchar        * gimp_image_projection_get_color_at (GimpImage       *gimage,
                                                    gint             x,
                                                    gint             y);

void            gimp_image_invalidate              (GimpImage       *gimage,
                                                    gint             x,
                                                    gint             y,
                                                    gint             w,
                                                    gint             h,
                                                    gint             x1,
                                                    gint             y1,
                                                    gint             x2,
                                                    gint             y2);
void          gimp_image_invalidate_without_render (GimpImage       *gimage,
                                                    gint             x,
                                                    gint             y,
                                                    gint             w,
                                                    gint             h,
                                                    gint             x1,
                                                    gint             y1,
                                                    gint             x2,
                                                    gint             y2);


#endif /* __GIMP_IMAGE_PROJECTION_H__ */

==> gimp-1.3.18.tar.bz2: gimp-1.3.18/app/core/gimpimage-projection.h <==
/* The GIMP -- an image manipulation program
 * Copyright (C) 1995 Spencer Kimball and Peter Mattisbvf
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __GIMP_IMAGE_PROJECTION_H__
#define __GIMP_IMAGE_PROJECTION_H__


void            gimp_image_projection_allocate     (GimpImage       *gimage);
void            gimp_image_projection_free         (GimpImage       *gimage);

TileManager   * gimp_image_projection              (GimpImage       *gimage);
GimpImageType	gimp_image_projection_type         (const GimpImage *gimage);
gint            gimp_image_projection_bytes        (const GimpImage *gimage);
gdouble         gimp_image_projection_opacity      (const GimpImage *gimage);

guchar        * gimp_image_projection_get_color_at (GimpImage       *gimage,
                                                    gint             x,
                                                    gint             y);

void            gimp_image_invalidate              (GimpImage       *gimage,
                                                    gint             x,
                                                    gint             y,
                                                    gint             w,
                                                    gint             h,
                                                    gint             x1,
                                                    gint             y1,
                                                    gint             x2,
                                                    gint             y2);
void          gimp_image_invalidate_without_render (GimpImage       *gimage,
                                                    gint             x,
                                                    gint             y,
                                                    gint             w,
                                                    gint             h,
                                                    gint             x1,
                                                    gint             y1,
                                                    gint             x2,
                                                    gint             y2);


#endif /* __GIMP_IMAGE_PROJECTION_H__ */
